@@ -12,7 +12,5 @@ class tanf_max_amount(Variable):
     def formula(spm_unit, period, parameters):
         household_size = spm_unit("spm_unit_size", period).astype(str)
         state = spm_unit.household("state_code_str", period)
-        max_amount = parameters(
-            period
-        ).hhs.tanf.cash.eligibility.continuous.income.limits
+        max_amount = parameters(period).hhs.tanf.cash.amount.max
         return max_amount[state][household_size] * MONTHS_IN_YEAR
