@@ -63,7 +63,16 @@ class section_22_income(Variable):
         total_pensions = add(tax_unit, period, ["pension_income"])
         taxable_pensions = add(tax_unit, period, ["taxable_pension_income"])
         non_taxable_pensions = total_pensions - taxable_pensions
-        capped_reduced_amount = capped_amount - non_taxable_pensions
+        total_social_security = tax_unit("tax_unit_social_security", period)
+        taxable_social_security = tax_unit(
+            "tax_unit_taxable_social_security", period
+        )
+        non_taxable_social_security = (
+            total_social_security - taxable_social_security
+        )
+        capped_reduced_amount = (
+            capped_amount - non_taxable_pensions - non_taxable_social_security
+        )
         agi = tax_unit("adjusted_gross_income", period)
 
         amount_over_phaseout = max_(
